@@ -56,6 +56,8 @@ extern "C" {
 #define GIALIAS_CDELT1 "CDELT1"
 #define GIALIAS_CTYPE1 "CTYPE1"
 #define GIALIAS_CUNIT1 "CUNIT1"
+#define GIALIAS_CRDER1 "CRDER1"
+#define GIALIAS_CSYER1 "CSYER1"
 #define GIALIAS_CRPIX2 "CRPIX2"
 #define GIALIAS_CRVAL2 "CRVAL2"
 #define GIALIAS_CDELT2 "CDELT2"
@@ -96,6 +98,8 @@ extern "C" {
 /* OBS */
 
 #define GIALIAS_TARGET  "ESO OBS TARG NAME"
+#define GIALIAS_PROGID  "ESO OBS PROG ID"
+#define GIALIAS_OBSID   "ESO OBS ID"
 
 /* TPL */
 
@@ -159,6 +163,9 @@ extern "C" {
 #define GIALIAS_BINX    "ESO DET WIN1 BINX"
 #define GIALIAS_BINY    "ESO DET WIN1 BINY"
 
+/* For backwards compatibility */
+
+#define GIALIAS_CONAD_LEGACY "ESO DET OUT CONAD"
 
 /* PRO */
 
@@ -172,6 +179,8 @@ extern "C" {
 #define GIALIAS_DATASIG    "ESO PRO DATARMS"
 #define GIALIAS_DATAMEAN   "ESO PRO DATAAVG"
 #define GIALIAS_DATAMEDI   "ESO PRO DATAMED"
+#define GIALIAS_PROPIPEID  "ESO PRO REC1 PIPE ID"
+#define GIALIAS_ANCESTOR   "ESO PRO ANCESTOR"
 
 /* QC */
 
@@ -428,6 +437,71 @@ extern "C" {
 
 #define GIALIAS_SKY_LEVEL   "ESO PRO SKY MEAN"
 
+/*
+ * Science Data Product keywords and default values.
+ */
+
+#define GIALIAS_PROCATG_COMMENT         "Pipeline product category"
+#define GIALIAS_PROCATG_RBNSPEC_IDP     "SCIENCE_RBNSPEC_IDP"
+#define GIALIAS_FIBER_SETUP             "FIBER_SETUP"
+#define GIALIAS_ORIGIN_VALUE            "ESO"
+#define GIALIAS_PRODLVL_VALUE           2
+#define GIALIAS_SPECSYS_VALUE           "HELIOCEN"
+#define GIALIAS_EXT_OBJ_VALUE           CPL_FALSE
+#define GIALIAS_PRODCATG_VALUE          "SCIENCE.SPECTRUM"
+#define GIALIAS_TIMESYS                 "TIMESYS"
+#define GIALIAS_M_EPOCH_VALUE           CPL_FALSE
+#define GIALIAS_FLUXCAL_VALUE           "UNCALIBRATED"
+#define GIALIAS_CONTNORM_VALUE          CPL_FALSE
+#define GIALIAS_TOTFLUX_VALUE           CPL_FALSE
+#define GIALIAS_FLUXERR_VALUE           -1
+#define GIALIAS_LAMNLIN                 "LAMNLIN"
+#define GIALIAS_LAMRMS                  "LAMRMS"
+#define GIALIAS_SPEC_ERR                "SPEC_ERR"
+#define GIALIAS_SPEC_SYE                "SPEC_SYE"
+#define GIALIAS_ASSOC_VALUE             "ANCILLARY.MOSSKY"
+#define GIALIAS_ASSO_PROCATG_VALUE      GIALIAS_ASSOC_VALUE
+#define GIALIAS_VOCLASS_VALUE           "SPECTRUM v2.0"
+#define GIALIAS_VOPUB_VALUE             "ESO/SAF"
+#define GIALIAS_APERTURE                "APERTURE"
+#define GIALIAS_APERTURE_VALUE          0.000334
+#define GIALIAS_APERTURE_COMMENT        "[deg] Angular fibre diameter"
+#define GIALIAS_FPS                     "FPS"
+#define GIALIAS_FPS_COMMENT             "Original FPS index"
+#define GIALIAS_GEOCORR                 "GEOCORR"
+#define GIALIAS_GEOCORR_COMMENT         "geocentric RV correction"
+#define GIALIAS_HELICORR                "HELICORR"
+#define GIALIAS_HELICORR_COMMENT        "heliocentric RV correction"
+#define GIALIAS_BARYCORR                "BARYCORR"
+#define GIALIAS_BARYCORR_COMMENT        "barycentric RV correction"
+#define GIALIAS_REFERENC                ""
+#define GIALIAS_COLUMN_INDEX            "INDEX"
+#define GIALIAS_COLUMN_OBJECT           "OBJECT"
+#define GIALIAS_COLUMN_TYPE             "TYPE"
+#define GIALIAS_COLUMN_RA               "RA"
+#define GIALIAS_COLUMN_DEC              "DEC"
+#define GIALIAS_COLUMN_GCORR            "GCORR"
+#define GIALIAS_COLUMN_HCORR            "HCORR"
+#define GIALIAS_COLUMN_BCORR            "BCORR"
+#define GIALIAS_COLUMN_WAVE             "WAVE"
+#define GIALIAS_COLUMN_WAVE_UNIT        "nm"
+#define GIALIAS_COLUMN_WAVE_TUTYP       "spec:Data.SpectralAxis.Value"
+#define GIALIAS_COLUMN_WAVE_TUCD        "em.wl"
+#define GIALIAS_COLUMN_WAVE_TCOMM       "Array computed from original WCS"
+#define GIALIAS_COLUMN_FLUX_REDUCED       "FLUX_REDUCED"
+#define GIALIAS_COLUMN_FLUX_REDUCED_UNIT  "adu"
+#define GIALIAS_COLUMN_FLUX_REDUCED_TUTYP "spec:Data.FluxAxis.Value"
+#define GIALIAS_COLUMN_FLUX_REDUCED_TUCD  "phot.flux.density;em.wl;stat.uncalib"
+#define GIALIAS_COLUMN_ERR_REDUCED        "ERR_REDUCED"
+#define GIALIAS_COLUMN_ERR_REDUCED_UNIT   "adu"
+#define GIALIAS_COLUMN_ERR_REDUCED_TUTYP  "spec:Data.FluxAxis.Accuracy.StatError"
+#define GIALIAS_COLUMN_ERR_REDUCED_TUCD   "stat.error;phot.flux.density;em.wl;stat.uncalib"
+#define GIALIAS_COLUMN_SNR              "SNR"
+#define GIALIAS_COLUMN_SNR_UNIT         ""
+#define GIALIAS_COLUMN_SNR_TUTYP        "eso:Data.FluxAxis.Accuracy.SNR"
+#define GIALIAS_COLUMN_SNR_TUCD         "stat.snr;meta.main"
+#define GIALIAS_COLUMN_SNR_TCOMM        "Array computed from flux and error arrays"
+
 
 /* deprecated */
 
